==> haskell-memotrie-0.6.9-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-9lFQw4taCukAwYMvMPHytn
key: MemoTrie-0.6.9-9lFQw4taCukAwYMvMPHytn
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: cb7d4a43cb96d403e3ee12f0bfa31f97
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-9lFQw4taCukAwYMvMPHytn
depends:
    base-4.11.1.0 newtype-generics-0.5.3-42woPvSQji8I6sT8i0yFK
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             newtype-generics-0.5.3-42woPvSQji8I6sT8i0yFK=c330b948d9bbfe2a7082bf16b70e29e2
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.9-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-EkJWFvsCpBIAMpwbUKtRe7
key: MemoTrie-0.6.9-EkJWFvsCpBIAMpwbUKtRe7
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: 70daa52c9fe878768650401827f7ceda
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-EkJWFvsCpBIAMpwbUKtRe7
depends:
    base-4.11.1.0 newtype-generics-0.5.3-4xFNB4Ddh669fqhBTPFlxe
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             newtype-generics-0.5.3-4xFNB4Ddh669fqhBTPFlxe=a7ba28b51afda96d435e2adc0ee94963
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
